=========
Changelog
=========

..
    You should *NOT* be adding new change log entries to this file, this
    file is managed by towncrier. You *may* edit previous change logs to
    fix problems like typo corrections or such.
    To add a new change log entry, please see
    https://docs.pulpproject.org/en/3.0/nightly/contributing/git.html#changelog-update

    WARNING: Don't drop the next directive!

.. towncrier release notes start

0.1.0a4 (2022-06-27)
====================

Bugfixes
--------

- Remove scheme from apache snippet
  `#8574 <https://pulp.plan.io/issues/8574>`_
- Adjusted the use of ``dispatch`` for pulpcore>=3.15. Also bumped the dependency.
  `#9533 <https://pulp.plan.io/issues/9533>`_


----


0.1.0a3 (2021-03-17)
====================

No significant changes.


----


0.1.0a2 (2020-11-25)
====================

No significant changes.


----


0.1.0a1 (2020-11-18)
====================

Features
--------

- Download a package with its dependencies
  `#6004 <https://pulp.plan.io/issues/6004>`_

